#
# Aura Engine (https://gitlab.servus.at/aura/engine)
#
# Copyright (C) 2017-2020 - The Aura Engine Team.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.



import logging
import threading

from modules.base.exceptions    import NoActiveScheduleException
from modules.base.utils         import SimpleUtil as SU


class StartupThread(threading.Thread):
    """
    StartupThread class.

    Boots the engine and starts playing the current schedule.
    """
    logger = None
    active_entry = None
    engine = None


    def __init__(self, engine):
        """
        Initialize the thread.
        """
        threading.Thread.__init__(self)
        self.logger = logging.getLogger("AuraEngine")
        self.engine = engine


    def run(self):
        """
        Boots the soundsystem.
        """
        try:
            self.engine.start()
            
        except NoActiveScheduleException as e:
            self.logger.info("Nothing scheduled at startup time. Please check if there are follow-up schedules.")
        except Exception as e:
            self.logger.error(SU.red("Error while initializing the soundsystem: " + str(e)), e)

